@@ -115,7 +115,7 @@ _EDITOR_SNIPPETS = {
         require("lspconfig").debputy.setup {capabilities = capabilities}
 
         # Make vim recognize debputy.manifest as YAML file
-        vim.filetype.add({filename = {["debputy.manifest"] = "yaml"})
+        vim.filetype.add({ filename = {["debputy.manifest"] = "yaml"} })
         """
     ),
 }
@@ -238,7 +238,7 @@ def lsp_editor_glue(context: CommandContext) -> None:
         print()
         choice = random.Random().choice(list(_EDITOR_SNIPPETS))
         print(
-            f"Use `debputy editor-config {choice}` (as an example) to see the instructions for a concrete editor."
+            f"Use `debputy lsp editor-config {choice}` (as an example) to see the instructions for a concrete editor."
         )
         return
     result = _EDITOR_SNIPPETS[editor_name]
