@@ -40,7 +40,7 @@ from debputy.lsp.maint_prefs import (
     EffectiveFormattingPreference,
     determine_effective_preference,
 )
-from debputy.lsp.quickfixes import provide_standard_quickfixes_from_diagnostics
+from debputy.lsp.quickfixes import provide_standard_quickfixes_from_diagnostics_lint
 from debputy.lsp.spellchecking import disable_spellchecking
 from debputy.lsp.text_edit import (
     get_well_formatted_edit,
@@ -518,7 +518,7 @@ def _auto_fix_run(
             if not _is_non_interactive_auto_fix_allowed(diagnostic):
                 unfixed_diagnostics.append(diagnostic)
                 continue
-            actions = provide_standard_quickfixes_from_diagnostics(
+            actions = provide_standard_quickfixes_from_diagnostics_lint(
                 CodeActionParams(
                     TextDocumentIdentifier(filename),
                     diagnostic.range,
@@ -664,7 +664,7 @@ def _diagnostics_run(
     with lint_report.line_state(lint_state):
         issues = lint_state.gather_diagnostics()
         for diagnostic in issues:
-            actions = provide_standard_quickfixes_from_diagnostics(
+            actions = provide_standard_quickfixes_from_diagnostics_lint(
                 CodeActionParams(
                     TextDocumentIdentifier(filename),
                     diagnostic.range,
