@@ -11,6 +11,7 @@ from typing import (
     Tuple,
     Literal,
     Set,
+    Dict,
 )
 
 import debputy.l10n as l10n
@@ -26,6 +27,7 @@ from debputy.linting.lint_util import (
     LinterImpl,
 )
 from debputy.lsp.apt_cache import AptCache
+from debputy.lsp.diagnostics import DiagnosticReport
 from debputy.lsp.maint_prefs import (
     MaintainerPreferenceTable,
     MaintainerPreference,
@@ -397,6 +399,7 @@ class DebputyLanguageServer(LanguageServer):
         self.client_locale: Optional[str] = None
         self.forced_locale: Optional[str] = None
         self._active_locale: Optional[List[str]] = None
+        self._diagnostic_reports: Dict[str, DiagnosticReport] = {}
 
     def finish_startup_initialization(self) -> None:
         if self._finished_initialization:
@@ -510,7 +513,7 @@ class DebputyLanguageServer(LanguageServer):
         try:
             return (
                 self.client_capabilities.text_document.hover.content_format
-            )  # type : ignore
+            )  # type: ignore
         except AttributeError:
             return None
 
@@ -590,3 +593,37 @@ class DebputyLanguageServer(LanguageServer):
             )
 
         return "filename", cleaned_filename, cleaned_filename
+
+    def close_document(self, uri: str) -> None:
+        try:
+            del self._diagnostic_reports[uri]
+        except KeyError:
+            pass
+
+    def record_diagnostics(
+        self,
+        uri: str,
+        version: int,
+        diagnostics: List[types.Diagnostic],
+    ) -> None:
+        self._diagnostic_reports[uri] = DiagnosticReport(
+            uri,
+            version,
+            f"{version}@{uri}",
+            False,
+            diagnostics,
+        )
+
+    def diagnostics_in_range(
+        self,
+        uri: str,
+        text_range: types.Range,
+    ) -> Optional[List[types.Diagnostic]]:
+        report = self._diagnostic_reports.get(uri)
+        if report is None or report.is_in_progress:
+            return None
+        doc = self.workspace.get_text_document(uri)
+        if doc.version is not None and doc.version != report.doc_version:
+            return None
+
+        return report.diagnostics_in_range(text_range)
