@@ -2,9 +2,6 @@ import dataclasses
 import importlib.resources
 import os.path
 import textwrap
-
-import debputy.lsp.data.deb822_data as deb822_ref_data_dir
-
 from functools import lru_cache
 from itertools import chain
 from typing import (
@@ -16,8 +13,10 @@ from typing import (
     List,
     Iterable,
     Self,
+    TYPE_CHECKING,
 )
 
+import debputy.lsp.data.deb822_data as deb822_ref_data_dir
 from debputy.analysis.analysis_util import flatten_ppfs
 from debputy.analysis.debian_dir import resolve_debhelper_config_files
 from debputy.dh.dh_assistant import extract_dh_compat_level
@@ -84,7 +83,6 @@ from debputy.lsprotocol.types import (
     CompletionItem,
     CompletionList,
     CompletionParams,
-    Location,
     HoverParams,
     Hover,
     TEXT_DOCUMENT_CODE_ACTION,
@@ -93,9 +91,7 @@ from debputy.lsprotocol.types import (
     WillSaveTextDocumentParams,
     TextEdit,
     DocumentFormattingParams,
-    InlayHintParams,
     InlayHint,
-    InlayHintLabelPart,
 )
 from debputy.manifest_parser.util import AttributePath
 from debputy.packager_provided_files import (
@@ -106,6 +102,11 @@ from debputy.plugin.api.impl import plugin_metadata_for_debputys_own_plugin
 from debputy.util import PKGNAME_REGEX, _info
 from debputy.yaml import MANIFEST_YAML
 
+if TYPE_CHECKING:
+    import lsprotocol.types as types
+else:
+    import debputy.lsprotocol.types as types
+
 try:
     from debputy.lsp.vendoring._deb822_repro.locatable import (
         Position as TEPosition,
@@ -351,11 +352,14 @@ def _render_package_lookup(
         segments.extend(
             [
                 f"Synopsis: {provider.synopsis}",
+                "",
                 f"Multi-Arch: {provider.multi_arch}",
+                "",
                 f"Section: {provider.section}",
             ]
         )
         if provider.upstream_homepage is not None:
+            segments.append("")
             segments.append(f"Upstream homepage: {provider.upstream_homepage}")
         segments.append("")
         segments.append(
@@ -596,7 +600,7 @@ def _debian_control_folding_ranges(
 @lsp_text_doc_inlay_hints(_DISPATCH_RULE)
 def _doc_inlay_hint(
     ls: "DebputyLanguageServer",
-    params: InlayHintParams,
+    params: types.InlayHintParams,
 ) -> Optional[List[InlayHint]]:
     doc = ls.workspace.get_text_document(params.text_document.uri)
     lint_state = ls.lint_state(doc)
@@ -616,18 +620,12 @@ def _doc_inlay_hint(
         pkg_kvpair = stanza.get_kvpair_element(("Package", 0), use_get=True)
         if pkg_kvpair is None:
             continue
-
-        inlay_hint_pos_te = pkg_kvpair.range_in_parent().end_pos.relative_to(
-            stanza_range.start_pos
-        )
-        inlay_hint_pos = doc.position_codec.position_to_client_units(
-            lint_state.lines,
-            te_position_to_lsp(inlay_hint_pos_te),
-        )
         stanza_def = _DCTRL_FILE_METADATA.classify_stanza(stanza, stanza_no)
+        parts = []
         for known_field in stanza_def.stanza_fields.values():
             if (
                 not known_field.inheritable_from_other_stanza
+                or not known_field.show_as_inherited
                 or known_field.name in stanza
             ):
                 continue
@@ -640,22 +638,41 @@ def _doc_inlay_hint(
                     lint_state.lines,
                     te_range_to_lsp(value_range_te),
                 )
-                inlay_hints.append(
-                    InlayHint(
-                        inlay_hint_pos,
-                        [
-                            InlayHintLabelPart(
-                                f"{known_field.name}: {inherited_value}\n",
-                                tooltip="Inherited from Source stanza",
-                                location=Location(
-                                    params.text_document.uri,
-                                    value_range,
-                                ),
-                            ),
-                        ],
-                    )
+                parts.append(
+                    types.InlayHintLabelPart(
+                        f"  ({known_field.name}: {inherited_value})",
+                        tooltip="Inherited from Source stanza",
+                        location=types.Location(
+                            params.text_document.uri,
+                            value_range,
+                        ),
+                    ),
                 )
 
+        if parts:
+            known_field = stanza_def["Package"]
+            values = known_field.field_value_class.interpreter().interpret(pkg_kvpair)
+            assert values is not None
+            anchor_value = list(values.iter_value_references())[-1]
+            anchor_position = (
+                anchor_value.locatable.range_in_parent().end_pos.relative_to(
+                    pkg_kvpair.value_element.position_in_parent().relative_to(
+                        stanza_range.start_pos
+                    )
+                )
+            )
+            anchor_position_client_units = doc.position_codec.position_to_client_units(
+                lint_state.lines,
+                te_position_to_lsp(anchor_position),
+            )
+            inlay_hints.append(
+                types.InlayHint(
+                    anchor_position_client_units,
+                    parts,
+                    padding_left=True,
+                    padding_right=False,
+                )
+            )
     return inlay_hints
 
 
@@ -822,7 +839,6 @@ def _scan_for_syntax_errors_and_token_level_diagnostics(
 
 @lint_diagnostics(_DISPATCH_RULE)
 def _lint_debian_control(lint_state: LintState) -> None:
-    doc_reference = lint_state.doc_uri
     deb822_file = lint_state.parsed_deb822_file_content
 
     first_error = _scan_for_syntax_errors_and_token_level_diagnostics(
@@ -871,7 +887,6 @@ def _lint_debian_control(lint_state: LintState) -> None:
             deb822_file,
             stanza,
             stanza_position,
-            doc_reference,
             lint_state,
             confusable_with_stanza_metadata=other_stanza_metadata,
             confusable_with_stanza_name=other_stanza_name,
