@@ -193,7 +193,6 @@ def _looks_like_a_dep5_file(
 
 @lint_diagnostics(_DISPATCH_RULE)
 def _lint_debian_copyright(lint_state: LintState) -> None:
-    doc_reference = lint_state.doc_uri
     deb822_file = lint_state.parsed_deb822_file_content
     stanzas = list(deb822_file)
 
@@ -219,7 +218,6 @@ def _lint_debian_copyright(lint_state: LintState) -> None:
             other_stanza_metadata = header_stanza
             other_stanza_name = "Header"
         elif "Format" in paragraph:
-            is_dep5 = True
             stanza_metadata = header_stanza
             other_stanza_metadata = files_stanza
             other_stanza_name = "Files/License"
@@ -230,7 +228,6 @@ def _lint_debian_copyright(lint_state: LintState) -> None:
             deb822_file,
             paragraph,
             paragraph_pos,
-            doc_reference,
             lint_state,
             confusable_with_stanza_name=other_stanza_name,
             confusable_with_stanza_metadata=other_stanza_metadata,
