@@ -203,13 +203,9 @@ def _conflicting_key(
         "error",
         "debputy",
         related_information=[
-            DiagnosticRelatedInformation(
-                location=Location(
-                    lint_state.doc_uri,
-                    key_b_range,
-                ),
-                message=f'The attribute "{key_b}" is used here.',
-            )
+            lint_state.related_diagnostic_information(
+                key_b_range, f'The attribute "{key_b}" is used here.'
+            ),
         ],
     )
 
@@ -219,13 +215,10 @@ def _conflicting_key(
         "error",
         "debputy",
         related_information=[
-            DiagnosticRelatedInformation(
-                location=Location(
-                    lint_state.doc_uri,
-                    key_a_range,
-                ),
-                message=f'The attribute "{key_a}" is used here.',
-            )
+            lint_state.related_diagnostic_information(
+                key_a_range,
+                f'The attribute "{key_a}" is used here.',
+            ),
         ],
     )
 
@@ -436,7 +429,9 @@ def _lint_content(
         known_packages = lint_state.binary_packages
         lc = content.lc
         for k, v in content.items():
-            if k is None or ("{{" not in k and known_packages is not None and k not in known_packages):
+            if k is None or (
+                "{{" not in k and known_packages is not None and k not in known_packages
+            ):
                 line, col = lc.key(k)
                 yaml_flag_unknown_key(
                     lint_state,
