@@ -393,7 +393,7 @@ def _emit_group(
     value = groups.get(group_name)
     if not value:
         return None
-    patch_start_col, patch_end_col = match.span(group_name)
+    patch_start_col = match.start(group_name)
     position_codec = sem_token_state.doc.position_codec
     patch_start_pos = position_codec.position_to_client_units(
         sem_token_state.lines,
