@@ -176,7 +176,6 @@ def _scan_for_syntax_errors_and_token_level_diagnostics(
 
 @lint_diagnostics(_DISPATCH_RULE)
 def _lint_debian_tests_control(lint_state: LintState) -> None:
-    doc_reference = lint_state.doc_uri
     deb822_file = lint_state.parsed_deb822_file_content
 
     first_error = _scan_for_syntax_errors_and_token_level_diagnostics(
@@ -198,7 +197,6 @@ def _lint_debian_tests_control(lint_state: LintState) -> None:
             deb822_file,
             paragraph,
             paragraph_pos,
-            doc_reference,
             lint_state,
         )
 
