@@ -9,7 +9,7 @@ from typing import (
 )
 
 from debputy.highlevel_manifest import MANIFEST_YAML
-from debputy.linting.lint_util import LintState
+from debputy.linting.lint_util import LintState, te_range_to_lsp
 from debputy.lsp.lsp_features import (
     lint_diagnostics,
     lsp_standard_handler,
@@ -577,13 +577,9 @@ def _conflicting_key(
         "error",
         "debputy",
         related_information=[
-            types.DiagnosticRelatedInformation(
-                location=types.Location(
-                    lint_state.doc_uri,
-                    key_b_range,
-                ),
-                message=f'The attribute "{key_b}" is used here.',
-            )
+            lint_state.related_diagnostic_information(
+                key_b_range, f'The attribute "{key_b}" is used here.'
+            ),
         ],
     )
 
@@ -593,13 +589,10 @@ def _conflicting_key(
         "error",
         "debputy",
         related_information=[
-            types.DiagnosticRelatedInformation(
-                location=types.Location(
-                    lint_state.doc_uri,
-                    key_a_range,
-                ),
-                message=f'The attribute "{key_a}" is used here.',
-            )
+            lint_state.related_diagnostic_information(
+                key_a_range,
+                f'The attribute "{key_a}" is used here.',
+            ),
         ],
     )
 
@@ -729,7 +722,6 @@ def _lint_content(
     elif isinstance(parser, InPackageContextParser):
         if not isinstance(content, CommentedMap):
             return
-        print(lint_state)
         known_packages = lint_state.binary_packages
         lc = content.lc
         for k, v in content.items():
