@@ -24,7 +24,6 @@ from typing import (
 
 from debian.debian_support import Version
 
-from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy._manifest_constants import MK_BUILDS
 from debputy.manifest_parser.base_types import (
     BuildEnvironmentDefinition,
@@ -70,6 +69,7 @@ from debputy.util import (
     PerlConfigVars,
     resolve_perl_config,
     generated_content_dir,
+    manifest_format_doc,
 )
 
 if TYPE_CHECKING:
@@ -176,7 +176,9 @@ def register_build_keywords(api: DebputyPluginInitializerProvider) -> None:
                     ),
                 ),
             ],
-            reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#build-environment-build-environment",
+            reference_documentation_url=manifest_format_doc(
+                f"build-environment-build-environment"
+            ),
         ),
     )
     api.pluggable_manifest_rule(
@@ -254,7 +256,9 @@ def register_build_keywords(api: DebputyPluginInitializerProvider) -> None:
                     ),
                 ),
             ],
-            reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#build-environment-build-environment",
+            reference_documentation_url=manifest_format_doc(
+                "build-environment-build-environment"
+            ),
         ),
     )
     api.pluggable_manifest_rule(
@@ -264,11 +268,46 @@ def register_build_keywords(api: DebputyPluginInitializerProvider) -> None:
         _handle_build_rules,
         expected_debputy_integration_mode=only_integrations(INTEGRATION_MODE_FULL),
         inline_reference_documentation=reference_documentation(
-            title="Build rules",
+            title=f"Build rules (`{MK_BUILDS}`)",
             description=textwrap.dedent(
                 """\
                 Define how to build the upstream part of the package. Usually this is done via "build systems",
                 which also defines the clean rules.
+
+                A simple example is:
+
+                ```yaml
+                    builds:
+                      - autoconf:
+                          configure-args:
+                            - "--enable-foo"
+                            - "--without=bar"
+                ```
+
+                Multiple builds are supported out of box. Here an example of how the build rules
+                for `libpam-krb5` might look.
+
+                ```yaml
+                    builds:
+                      - autoconf:
+                          for: libpam-krb5
+                          install-directly-to-package: true
+                          configure-args:
+                            - "--enable-reduced-depends"
+                            - "--with-krb5-include=/usr/include/mit-krb5"
+                            - "--with-krb5-lib=/usr/lib/{{DEB_HOST_MULTIARCH}}/mit-krb5"
+                            - "--with-kadm-client-include=/usr/include/mit-krb5"
+                            - "--with-kadm-client-lib=/usr/lib/{{DEB_HOST_MULTIARCH}}/mit-krb5"
+                      - autoconf:
+                          for: libpam-heimdal
+                          install-directly-to-package: true
+                          configure-args:
+                            - "--enable-reduced-depends"
+                            - "--with-krb5-include=/usr/include/heimdal"
+                            - "--with-krb5-lib=/usr/lib/{{DEB_HOST_MULTIARCH}}/heimdal"
+                            - "--with-kadm-client-include=/usr/include/heimdal"
+                            - "--with-kadm-client-lib=/usr/lib/{{DEB_HOST_MULTIARCH}}/heimdal"
+                ```
             """
             ),
         ),
@@ -1648,10 +1687,14 @@ class MesonBuildSystemRule(StepBasedBuildSystemRule):
         env_mod = EnvironmentModification(
             replacements=(("MESON_TESTTHREADS", f"{context.parallelization_limit()}"),),
         ).combine(self._default_meson_env())
+        meson_args = []
+        if not context.is_terse_build:
+            meson_args.append("--verbose")
         with self.dump_logs_on_error("meson-logs/testlog.txt"):
             run_build_system_command(
                 "meson",
                 "test",
+                *meson_args,
                 env_mod=env_mod,
                 cwd=self.build_directory,
             )
@@ -1951,7 +1994,7 @@ class ParsedMakeBuildRuleDefinition(
     AutoconfBuildSystemRule,
     auto_detection_shadows_build_systems=["debhelper", "make"],
     online_reference_documentation=reference_documentation(
-        title="Autoconf Build System",
+        title="Autoconf Build System (`autoconf`)",
         description=textwrap.dedent(
             """\
         Run an autoconf-based build system as the upstream build system.
@@ -2000,7 +2043,7 @@ class ParsedAutoconfBuildRuleDefinition(
     CMakeBuildSystemRule,
     auto_detection_shadows_build_systems=["debhelper", "make"],
     online_reference_documentation=reference_documentation(
-        title="CMake Build System",
+        title="CMake Build System (`cmake`)",
         description=textwrap.dedent(
             """\
         Run an cmake-based build system as the upstream build system.
@@ -2017,6 +2060,19 @@ class ParsedAutoconfBuildRuleDefinition(
                 """
                 ),
             ),
+            documented_attr(
+                "target_build_system",
+                textwrap.dedent(
+                    """\
+                    Which build system should `cmake` should delegate the build system to.
+                    In `cmake` terms, this is a Generator (the `-G` option).
+
+                    Supported options are:
+                     * `make` - GNU Make
+                     * `ninja` - Ninja
+                """
+                ),
+            ),
             *docs_from(
                 DebputyParsedContentStandardConditional,
                 OptionalInstallDirectly,
@@ -2039,7 +2095,7 @@ class ParsedCMakeBuildRuleDefinition(
     MesonBuildSystemRule,
     auto_detection_shadows_build_systems=["debhelper", "make"],
     online_reference_documentation=reference_documentation(
-        title="Meson Build System",
+        title="Meson Build System (`meson`)",
         description=textwrap.dedent(
             """\
         Run an meson-based build system as the upstream build system.
@@ -2081,7 +2137,7 @@ class ParsedMesonBuildRuleDefinition(
         "perl-makemaker",
     ],
     online_reference_documentation=reference_documentation(
-        title='Perl "Build.PL" Build System',
+        title='Perl "Build.PL" Build System (`perl-build`)',
         description=textwrap.dedent(
             """\
         Build using the `Build.PL` Build system used by some Perl packages.
@@ -2117,7 +2173,7 @@ class ParsedPerlBuildBuildRuleDefinition(
     "debhelper",
     DebhelperBuildSystemRule,
     online_reference_documentation=reference_documentation(
-        title="Debhelper Build System",
+        title="Debhelper Build System (`debhelper`)",
         description=textwrap.dedent(
             """\
         Delegate to a debhelper provided build system
@@ -2177,7 +2233,7 @@ class ParsedDebhelperBuildRuleDefinition(
         "make",
     ],
     online_reference_documentation=reference_documentation(
-        title='Perl "MakeMaker" Build System',
+        title='Perl "MakeMaker" Build System (`perl-makemaker`)',
         description=textwrap.dedent(
             """\
         Build using the "MakeMaker" Build system used by some Perl packages.
@@ -2218,7 +2274,7 @@ class ParsedPerlMakeMakerBuildRuleDefinition(
         # Open question, should this shadow "qmake6" and later?
     ],
     online_reference_documentation=reference_documentation(
-        title='QT "qmake" Build System',
+        title='QT "qmake" Build System (`qmake`)',
         description=textwrap.dedent(
             """\
         Build using the "qmake" by QT.
@@ -2255,7 +2311,7 @@ class ParsedQmakeBuildRuleDefinition(ParsedGenericQmakeBuildRuleDefinition):
         "make",
     ],
     online_reference_documentation=reference_documentation(
-        title='QT "qmake6" Build System',
+        title='QT "qmake6" Build System (`qmake6`)',
         description=textwrap.dedent(
             """\
         Build using the "qmake6" from the `qmake6` package.  This is like the `qmake` system
