@@ -1,5 +1,5 @@
 import collections
-from typing import List, Optional, Mapping, Any, Callable, Sequence
+from typing import List, Optional, Mapping, Any, Callable, Sequence, TYPE_CHECKING
 
 import pytest
 
@@ -16,7 +16,10 @@ from debputy.lsp.maint_prefs import (
 from debputy.packages import DctrlParser
 from debputy.plugin.api.feature_set import PluginProvidedFeatureSet
 
-from debputy.lsprotocol.types import Diagnostic, DiagnosticSeverity, Range
+if TYPE_CHECKING:
+    from lsprotocol import types
+else:
+    from debputy.lsprotocol import types
 
 
 try:
@@ -34,7 +37,7 @@ class LintWrapper:
     def __init__(
         self,
         path: str,
-        handler: Callable[[LintState], Optional[List[Diagnostic]]],
+        handler: Callable[[LintState], Optional[List[types.Diagnostic]]],
         debputy_plugin_feature_set: PluginProvidedFeatureSet,
         dctrl_parser: DctrlParser,
     ) -> None:
@@ -47,7 +50,7 @@ class LintWrapper:
         self.lint_maint_preference_table = MaintainerPreferenceTable({}, {})
         self.effective_preference: Optional[EffectiveFormattingPreference] = None
 
-    def __call__(self, lines: List[str]) -> List["Diagnostic"]:
+    def __call__(self, lines: List[str]) -> List["types.Diagnostic"]:
         source_package = None
         binary_packages = None
         dctrl_lines = self.dctrl_lines
@@ -82,8 +85,8 @@ def requires_levenshtein(func: Any) -> Any:
 
 
 def check_diagnostics(
-    diagnostics: Optional[List["Diagnostic"]],
-) -> List["Diagnostic"]:
+    diagnostics: Optional[List["types.Diagnostic"]],
+) -> List["types.Diagnostic"]:
     if diagnostics:
         for diagnostic in diagnostics:
             assert diagnostic.severity is not None
@@ -93,15 +96,15 @@ def check_diagnostics(
     return diagnostics
 
 
-def by_range_sort_key(diagnostic: Diagnostic) -> Any:
+def by_range_sort_key(diagnostic: types.Diagnostic) -> Any:
     start_pos = diagnostic.range.start
     end_pos = diagnostic.range.end
     return start_pos.line, start_pos.character, end_pos.line, end_pos.character
 
 
 def group_diagnostics_by_severity(
-    diagnostics: Optional[List["Diagnostic"]],
-) -> Mapping["DiagnosticSeverity", List["Diagnostic"]]:
+    diagnostics: Optional[List["types.Diagnostic"]],
+) -> Mapping["types.DiagnosticSeverity", List["types.Diagnostic"]]:
     if not diagnostics:
         return {}
 
@@ -115,7 +118,7 @@ def group_diagnostics_by_severity(
     return by_severity
 
 
-def diag_range_to_text(lines: Sequence[str], range_: "Range") -> str:
+def diag_range_to_text(lines: Sequence[str], range_: "types.Range") -> str:
     parts = []
     for line_no in range(range_.start.line, range_.end.line + 1):
         line = lines[line_no]
